==> teamapps-client-0.9.6.zip: tsd/modules/util/UiGridTemplates.d.ts <==
import { Renderer } from "../Common";
import { IconPathProvider } from "../TeamAppsUiContext";
import { UiTextElementConfig } from "../../generated/UiTextElementConfig";
import { UiBadgeElementConfig } from "../../generated/UiBadgeElementConfig";
import { UiFloatingElementConfig } from "../../generated/UiFloatingElementConfig";
import { UiImageElementConfig } from "../../generated/UiImageElementConfig";
import { UiIconElementConfig } from "../../generated/UiIconElementConfig";
import { UiGlyphIconElementConfig } from "../../generated/UiGlyphIconElementConfig";
import { AbstractUiTemplateElementConfig } from "../../generated/AbstractUiTemplateElementConfig";
import { UiGridTemplateConfig } from "../../generated/UiGridTemplateConfig";
export declare function isUiTextElement(element: AbstractUiTemplateElementConfig): element is UiTextElementConfig;
export declare function isUiBadgeElement(element: AbstractUiTemplateElementConfig): element is UiBadgeElementConfig;
export declare function isUiFloatingElement(element: AbstractUiTemplateElementConfig): element is UiFloatingElementConfig;
export declare function isUiImageElement(element: AbstractUiTemplateElementConfig): element is UiImageElementConfig;
export declare function isUiIconElement(element: AbstractUiTemplateElementConfig): element is UiIconElementConfig;
export declare function isUiGlyphIconElement(element: AbstractUiTemplateElementConfig): element is UiGlyphIconElementConfig;
export declare function createGridTemplateRenderer(template: UiGridTemplateConfig, iconPathProvider: IconPathProvider, idPropertyName: string): Renderer;

==> teamapps-client-0.9.183.zip: tsd/modules/util/UiGridTemplates.d.ts <==
import { Renderer } from "../Common";
import { UiTextElementConfig } from "../../generated/UiTextElementConfig";
import { UiBadgeElementConfig } from "../../generated/UiBadgeElementConfig";
import { UiFloatingElementConfig } from "../../generated/UiFloatingElementConfig";
import { UiImageElementConfig } from "../../generated/UiImageElementConfig";
import { UiIconElementConfig } from "../../generated/UiIconElementConfig";
import { UiGlyphIconElementConfig } from "../../generated/UiGlyphIconElementConfig";
import { AbstractUiTemplateElementConfig } from "../../generated/AbstractUiTemplateElementConfig";
import { UiGridTemplateConfig } from "../../generated/UiGridTemplateConfig";
export declare function isUiTextElement(element: AbstractUiTemplateElementConfig): element is UiTextElementConfig;
export declare function isUiBadgeElement(element: AbstractUiTemplateElementConfig): element is UiBadgeElementConfig;
export declare function isUiFloatingElement(element: AbstractUiTemplateElementConfig): element is UiFloatingElementConfig;
export declare function isUiImageElement(element: AbstractUiTemplateElementConfig): element is UiImageElementConfig;
export declare function isUiIconElement(element: AbstractUiTemplateElementConfig): element is UiIconElementConfig;
export declare function isUiGlyphIconElement(element: AbstractUiTemplateElementConfig): element is UiGlyphIconElementConfig;
export declare function createGridTemplateRenderer(template: UiGridTemplateConfig, idPropertyName: string): Renderer;
